==> irc-2.1.1.tar.gz: README.md <==
# Dart IRC [![Build Status](https://travis-ci.org/DirectMyFile/irc.dart.svg?branch=master)](https://travis-ci.org/DirectMyFile/irc.dart) [![Latest Version](https://img.shields.io/badge/pub-2.1.1-blue.svg)](https://pub.dartlang.org/packages/irc)

The Beautiful IRC Library for Dart

## Links

- [Wiki](https://github.com/DirectMyFile/irc.dart/wiki/Home)
- [Issue Tracker](https://github.com/DirectMyFile/irc.dart/issues)
- [Pub Package](https://pub.dartlang.org/packages/irc)

## Get Started

Visit the [Getting Started](https://github.com/DirectMyFile/irc.dart/wiki/Getting-Started) wiki page.

## Design

irc.dart is designed to be the one-stop shop for all your irc needs in Dart.

- Different Functions split into Libraries
- Client API
- Parsing API
- Bot API
- Event Based

**Fully Supported Servers**:
- [Charybdis](https://github.com/atheme/charybdis)

**Partially Supported Servers**:
- [UnrealIRCd](http://www.unrealircd.com/)

**Tested On**:
- [EsperNet](https://www.esper.net/)
- [Freenode](https://freenode.net/)

We are looking for others to help work on better server support. See [Contacting Us](#contacting-us).

## Contacting Us

You can find us on `irc.esper.net` at `#directcode`. Just mention you wanna help with the Dart IRC library, and we will be happy to assist you!

## Contributing

See the [Contributing Guide](https://github.com/DirectMyFile/irc.dart/blob/master/CONTRIBUTING.md).

## Notices

irc.dart is a no-license project. We really don't care what you do. Use it and abuse it.

==> irc-3.0.0.tar.gz: README.md <==
# Dart IRC [![Build Status](https://travis-ci.org/DirectMyFile/irc.dart.svg?branch=master)](https://travis-ci.org/DirectMyFile/irc.dart) [![Latest Version](https://img.shields.io/badge/pub-3.0.0-blue.svg)](https://pub.dartlang.org/packages/irc)

The Beautiful IRC Library for Dart

## Links

- [Wiki](https://github.com/DirectMyFile/irc.dart/wiki/Home)
- [Issue Tracker](https://github.com/DirectMyFile/irc.dart/issues)
- [Pub Package](https://pub.dartlang.org/packages/irc)

## Get Started

Visit the [Getting Started](https://github.com/DirectMyFile/irc.dart/wiki/Getting-Started) wiki page.

## Design

irc.dart is designed to be the one-stop shop for all your irc needs in Dart.

- Different Functions split into Libraries
- Client API
- Parsing API
- Bot API
- Event Based

**Fully Supported Servers**:
- [Charybdis](https://github.com/atheme/charybdis)

**Partially Supported Servers**:
- [UnrealIRCd](http://www.unrealircd.com/)

**Tested On**:
- [EsperNet](https://www.esper.net/)
- [Freenode](https://freenode.net/)

We are looking for others to help work on better server support. See [Contacting Us](#contacting-us).

## Contacting Us

You can find us on `irc.esper.net` at `#directcode`. Just mention you want help with the Dart IRC
library, and we will be happy to assist you!

## Contributing

See the [Contributing Guide](https://github.com/DirectMyFile/irc.dart/blob/master/CONTRIBUTING.md).

## Notices

irc.dart is licensed under the MIT license. We really don't care what you do. Use it and abuse it.
